@@ -25,29 +25,8 @@
 #include <glade/glade-xml.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcolorbutton.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkfontbutton.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreeviewcolumn.h>
-#include <gtk/gtktextbuffer.h>
-#include <gtk/gtktextview.h>
-#include <gtk/gtktextiter.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrenderertoggle.h>
-#include <gtk/gtklabel.h>
-#include <glib/gprintf.h>
+#include <gtk/gtk.h>
+#include <glib.h>
 
 #include "mud-preferences-window.h"
 #include "mud-profile.h"
@@ -1071,6 +1050,10 @@ static void
 mud_preferences_window_proxy_check_cb(GtkWidget *widget, MudPreferencesWindow *window)
 {
 	gboolean value = GTK_TOGGLE_BUTTON(widget)->active ? TRUE : FALSE;
+
+	gtk_widget_set_sensitive(window->priv->proxy_entry, value);
+	gtk_widget_set_sensitive(window->priv->proxy_combo, value);
+
 	RETURN_IF_CHANGING_PROFILES(window);
 
 	mud_profile_set_proxy_check(window->priv->profile, value);
