@@ -22,25 +22,11 @@
 
 #include <glade/glade-xml.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkimage.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkimage.h>
-#include <gdk/gdkpixbuf.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkpaned.h>
-#include <gtk/gtktextview.h>
-#include <gtk/gtktextbuffer.h>
-#include <gtk/gtktextiter.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkprogressbar.h>
+#include <gdk/gdk.h>
 #include <vte/vte.h>
-#include <glib/gstring.h>
+#include <glib.h>
 #include <string.h>
 #include <stdlib.h>
 
@@ -49,13 +35,12 @@
 #include "mud-connection-view.h"
 #include "mud-preferences-window.h"
 #include "mud-window.h"
-#include "mud-window-mudlist.h"
 #include "mud-tray.h"
-#include "mud-window-mconnect.h"
 #include "modules.h"
 #include "mud-profile.h"
 #include "mud-window-profile.h"
 #include "mud-parse-base.h"
+#include "mud-connections.h"
 
 struct _MudWindowPrivate
 {
@@ -392,12 +377,6 @@ mud_window_preferences_cb(GtkWidget *widget, MudWindow *window)
 	mud_preferences_window_new("Default");
 }
 
-static void
-mud_window_list_cb(GtkWidget *widget, MudWindow *window)
-{
-	mud_window_mudlist_new();
-}
-
 static void
 mud_window_profiles_cb(GtkWidget *widget, MudWindow *window)
 {
@@ -408,10 +387,10 @@ static void
 mud_window_about_cb(GtkWidget *widget, MudWindow *window)
 {
     static const gchar * const authors[] = {
-        "Robin Ericsson <lobbin@localhost.nu>",
+        "Les Harris <lharris@gnome.org>",
         "Jordi Mallach <jordi@sindominio.net>",
         "Daniel Patton <seven-nation@army.com>",
-        "Les Harris <me@lesharris.com>",
+	"Robin Ericsson <lobbin@localhost.nu>",
         NULL
     };
 
@@ -444,7 +423,7 @@ mud_window_about_cb(GtkWidget *widget, MudWindow *window)
         "translator-credits", _("translator-credits"),
         "version", VERSION,
         "website", "http://live.gnome.org/GnomeMud",
-        "name", "gnome-mud",
+        "name", "Gnome-Mud",
         NULL);
 
     if(logo)
@@ -454,11 +433,7 @@ mud_window_about_cb(GtkWidget *widget, MudWindow *window)
 static void
 mud_window_mconnect_dialog(GtkWidget *widget, MudWindow *window)
 {
-	GtkWidget *mywig;
-
-	mywig = window->priv->window;
-
-	mud_window_mconnect_new(window, mywig, window->priv->tray);
+	mud_connections_new(window, window->priv->window, window->priv->tray);
 }
 
 gboolean
@@ -476,6 +451,8 @@ mud_window_size_request(GtkWidget *widget, GdkEventConfigure *event, gpointer us
 		buf = gdk_pixbuf_new_from_file_at_size(GMPIXMAPSDIR "/gnome-mud.svg", w >> 1, h >> 1, &gerr);
 
 		gtk_image_set_from_pixbuf(GTK_IMAGE(window->priv->image), buf);
+
+		g_object_unref(buf);
 	}
 
 	gtk_widget_grab_focus(window->priv->textview);
@@ -585,7 +562,9 @@ mud_window_buffer_cb(GtkWidget *widget, MudWindow *window)
 											NULL,
 											NULL);
 
-			fwrite(bufferText, 1, strlen(bufferText), file);
+			if(!fwrite(bufferText, 1, strlen(bufferText), file))
+				g_critical(_("Could not write buffer to disk!"));
+
 			fclose(file);
 		}
 
@@ -755,8 +734,8 @@ mud_window_init (MudWindow *window)
 	/* connect connect buttons */
 	g_signal_connect(glade_xml_get_widget(glade, "main_connect"), "activate", G_CALLBACK(mud_window_mconnect_dialog), window);
 	g_signal_connect(glade_xml_get_widget(glade, "menu_connect"), "activate", G_CALLBACK(mud_window_connect_dialog), window);
-	g_signal_connect(glade_xml_get_widget(glade, "menu_mudlist"), "activate",
-G_CALLBACK(mud_window_list_cb), window);
+	/*g_signal_connect(glade_xml_get_widget(glade, "menu_mudlist"), "activate",
+G_CALLBACK(mud_window_list_cb), window);*/
 	g_signal_connect(glade_xml_get_widget(glade, "toolbar_connect"), "clicked", G_CALLBACK(mud_window_connect_dialog), window);
 
 	/* connect disconnect buttons */
